@@ -11,8 +11,6 @@ from pathlib import Path
 from typing import TYPE_CHECKING
 from typing import Any
 
-from poetry.core.masonry.utils.helpers import escape_name
-from poetry.core.masonry.utils.helpers import escape_version
 from poetry.core.packages.package import Package
 from poetry.core.packages.utils.link import Link
 from poetry.core.toml.file import TOMLFile
@@ -31,8 +29,8 @@ from poetry.utils._compat import metadata
 if TYPE_CHECKING:
     from collections.abc import Iterator
 
+    from poetry.core.constraints.version import Version
     from poetry.core.packages.dependency import Dependency
-    from poetry.core.semver.version import Version
     from pytest_mock import MockerFixture
     from tomlkit.toml_document import TOMLDocument
 
@@ -183,7 +181,7 @@ class PoetryTestApplication(Application):
         self._poetry.set_pool(poetry.pool)
         self._poetry.set_config(poetry.config)
         self._poetry.set_locker(
-            TestLocker(poetry.locker.lock.path, self._poetry.local_config)
+            TestLocker(poetry.locker.lock, self._poetry.local_config)
         )
 
 
@@ -236,8 +234,8 @@ class TestRepository(Repository):
     def find_links_for_package(self, package: Package) -> list[Link]:
         return [
             Link(
-                f"https://foo.bar/files/{escape_name(package.name)}"
-                f"-{escape_version(package.version.text)}-py2.py3-none-any.whl"
+                f"https://foo.bar/files/{package.name.replace('-', '_')}"
+                f"-{package.version.to_string()}-py2.py3-none-any.whl"
             )
         ]
 
